﻿using System;
using System.Linq;
using System.IO;
using System.IO.IsolatedStorage;
using System.Collections.Generic;
using Microsoft.LightSwitch;
using Microsoft.LightSwitch.Framework.Client;
using Microsoft.LightSwitch.Presentation;
using Microsoft.LightSwitch.Presentation.Extensions;
using System.Windows.Controls;
using System.Windows.Data;

namespace LightSwitchApplication
{
    public partial class SalesDisplayByQuarter
    {
        partial void SalesDisplayByQuarter_Created()
        {
            // Write your code here.
            this.SaleQuarter = 1;

            var ctrlProxy = this.FindControl("BindableSlider");
            ctrlProxy.SetBinding(Slider.ValueProperty, "Value", BindingMode.TwoWay);
            ctrlProxy.ControlAvailable += 
                new EventHandler<ControlAvailableEventArgs>(ctrlProxy_ControlAvailable);
        }

        void ctrlProxy_ControlAvailable(object sender, ControlAvailableEventArgs e)
        {
            // Remove Control Handler
            this.FindControl("BindableSlider").
                ControlAvailable -= ctrlProxy_ControlAvailable;

            // Set defaults for Slider
            Slider SliderControl = e.Control as Slider;
            SliderControl.Maximum = 4;
            SliderControl.Minimum = 1;
        }

        int intLastSalesQuarter = -1;
        partial void SaleQuarter_Changed()
        {
            // Check to see if the Quarter actually changed to prevent looping
            if (intLastSalesQuarter != this.SaleQuarter)
            {
                intLastSalesQuarter = this.SaleQuarter;

                // Remove any unsaved Sales                
                foreach (Sale sale in this.DataWorkspace.ApplicationData.Details.GetChanges()
                    .AddedEntities.OfType<Sale>())
                {
                    sale.Details.DiscardChanges();
                }

                // Get all SalesPersons who do not have Sales for the Quarter
                int[] intSalesPersonsWithoutSales = (from objSalesPersons in SalesPersons
                                                     where objSalesPersons.Sales.
                                                     FirstOrDefault(x => x.SaleQuarter 
                                                         == SaleQuarter) == null
                                                     select objSalesPersons.Id).ToArray();

                int intTempID = -1;
                // Loop through the SalePersons
                foreach (int item in intSalesPersonsWithoutSales)
                {
                    // Get the SalesPerson record
                    SalesPerson objSalesPerson = 
                        DataWorkspace.ApplicationData.SalesPersons_Single(item);

                    // Create a Sale for the SalesPerson
                    Sale objSale = objSalesPerson.Sales.AddNew();

                    objSale.Sales = 0;
                    objSale.SaleQuarter = SaleQuarter;
                    objSale.SalesPerson = objSalesPerson;
                    // We need to give each record a unique ID 
                    // So we insert negative numbers and count backwards
                    objSale.Id = intTempID;
                    intTempID--;
                }
            }
        }



    }
}
